<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://www.spip.net/oc',
'0_langue' => 'occitan (auvernhat) [oc_auv]',
'0_liste' => 'spip-oc@rezo.net',
'0_mainteneur' => 'Domergue Sumien: lenga.occitana@aprene.org ',

// A
'access_interface_graphique' => 'Tornar a l\'interf&agrave;cia grafica completa',
'access_mode_texte' => 'Afichar l\'interf&agrave;cia textuala simplificada',
'admin_debug' => 'desbugatge',
'admin_modifier_article' => 'Modificar aquel article',
'admin_modifier_auteur' => 'Modificar aquel autor',
'admin_modifier_breve' => 'Modificar aquela br&egrave;va',
'admin_modifier_mot' => 'Modificar aquel mot clau',
'admin_modifier_rubrique' => 'Modificar aquela rubrica',
'admin_recalculer' => 'Tornar calcular la pagina',
'afficher_trad' => 'afficher les traductions', # NEW
'alerte_maj_impossible' => '<b>Al&egrave;rta!</b> Quo es impossible d\'actualizar la basa SQL v&egrave;rs la version @version@; benl&egrave;u i a un probl&egrave;ma relatiu au dreit de modificar la basa de donadas. Volhatz contactar v&ograve;stre auberjador.',
'alerte_modif_info_concourante' => 'ATTENTION : Cette information a &eacute;t&eacute; modifi&eacute;e par ailleurs. La valeur actuelle est&nbsp;:', # NEW
'analyse_xml' => 'Analisi XML',
'annuler' => 'Annuler', # NEW
'antispam_champ_vide' => 'Veuillez laisser ce champ vide&nbsp;:', # NEW
'articles_recents' => 'Los articles mai recents',
'avis_archive_incorrect' => 'lo fich&egrave;ir archiu z-es pas un fich&egrave;ir SPIP',
'avis_archive_invalide' => 'lo fich&egrave;ir archiu z-es pas valid',
'avis_attention' => 'ATENCION!',
'avis_champ_incorrect_type_objet' => 'Nom de champ incorr&egrave;cte @name@ per obj&egrave;cte de tipe @type@',
'avis_colonne_inexistante' => 'La colomna @col@ exist&iacute;s pas',
'avis_echec_syndication_01' => 'La sindicacion a patracat: lo backend indicat z-es indeschifrable o prepausa gran d\'article.',
'avis_echec_syndication_02' => 'La sindicacion a partacat: impossible d\'accedir v&egrave;rs lo backend d\'aquel sit.',
'avis_erreur' => 'Error: vejatz &ccedil;ai sos',
'avis_erreur_connexion' => 'Error de connexion',
'avis_erreur_cookie' => 'probl&egrave;ma de cookie',
'avis_erreur_fonction_contexte' => 'Error de programacion. Chau pas cridar aquela foncion dins aquel cont&egrave;xt.',
'avis_erreur_mysql' => 'Error SQL ',
'avis_erreur_sauvegarde' => 'Error dins la sauvagarda (@type@ @id_objet@)! ',
'avis_erreur_visiteur' => 'Probl&egrave;me d\'acc&egrave;s &agrave; l\'espace priv&eacute;', # NEW

// B
'barre_a_accent_grave' => 'Inserir una A accent gr&egrave;u majuscula',
'barre_aide' => 'Utilizar las \'corchas tipograficas per enrichir v&ograve;stra compaginacion',
'barre_e_accent_aigu' => 'Inserir una E accent agut majuscula',
'barre_eo' => 'Inserir una E dins l\'O',
'barre_eo_maj' => 'Inserir una E dins l\'O majuscula',
'barre_euro' => 'Inserir lo simb&egrave;u de l\'&egrave;uro: &euro;',
'barre_gras' => 'Metre en {{gras}}',
'barre_guillemets' => 'Enrodar amb de &laquo; vergetas &raquo;',
'barre_guillemets_simples' => 'Enrodar amb de „vergetas“',
'barre_intertitre' => 'Transformar en {{{intert&iacute;tol}}}',
'barre_italic' => 'Metre en {italics}',
'barre_lien' => 'Transformar en [liam ipert&egrave;xt->http://...]',
'barre_lien_input' => 'Volhatz indicar l\'adrei&ccedil;a de v&ograve;stre liam (pod&egrave;tz indicar una adrei&ccedil;a web sos la forma http://www.lomieusit.com o simplament indicar lo num&egrave;ro d\'un article d\'aquel sit).',
'barre_note' => 'Transformar en [[N&ograve;ta de p&egrave;]]',
'barre_paragraphe' => 'Cr&#233;er un paragraphe', # NEW
'barre_quote' => '<quote>Citar un messatge</quote>',
'bouton_ajouter_document' => 'APONDRE UN DOCUMENT', # MODIF
'bouton_ajouter_image' => 'APONDRE UN IMATGE', # MODIF
'bouton_ajouter_image_document' => 'Ajouter une image ou&nbsp;un&nbsp;document', # NEW
'bouton_changer' => 'Chamjar',
'bouton_chercher' => 'Cerchar',
'bouton_choisir' => 'Chausir',
'bouton_download' => 'T&eacute;l&eacute;charger', # NEW
'bouton_enregistrer' => 'Registrar',
'bouton_radio_desactiver_messagerie_interne' => 'Desactivar la messatjari&aacute; int&egrave;rna',
'bouton_radio_envoi_annonces' => 'Mandar los anoncis editoriaus',
'bouton_radio_non_envoi_annonces' => 'Pas mandar d\'anoncis',
'bouton_radio_non_envoi_liste_nouveautes' => 'Pas mandar la t&egrave;ira de las novetats',
'bouton_recharger_page' => 'tornar charjar aquela pagina',
'bouton_telecharger' => 'Telecharjar',
'bouton_valider' => 'Validar',

// C
'cal_apresmidi' => 'tant&ograve;st',
'cal_jour_entier' => 'jorn enti&egrave;r',
'cal_matin' => 'matin',
'cal_par_jour' => 'chalend&egrave;ir per jorn',
'cal_par_mois' => 'chalend&egrave;ir per mes',
'cal_par_semaine' => 'chalend&egrave;ir per setmana',
'choix_couleur_interface' => 'couleur ', # NEW
'choix_interface' => 'choix  de l\'interface', # NEW
'colonne' => 'Colonne', # NEW
'confirm_changer_statut' => 'Atencion, av&egrave;tz demandat de chamjar l\'estatut d\'aquel element. Desiratz de contunhar? ',
'correcte' => 'correcte', # chaine utilis&eacute;e dans le debugueur : "validation .. impossible" ou "validation .. correcte" NEW

// D
'date_aujourdhui' => 'anu&egrave;i lo jorn',
'date_avant_jc' => 'avans lo Crist',
'date_dans' => 'd\'aqu&iacute; @delai@',
'date_de_mois_1' => '@j@ de girv&egrave;ir',
'date_de_mois_10' => '@j@ d\'oct&ograve;bre',
'date_de_mois_11' => '@j@ de novembre',
'date_de_mois_12' => '@j@ de decembre',
'date_de_mois_2' => '@j@ de feur&egrave;ir',
'date_de_mois_3' => '@j@ de mar&ccedil;',
'date_de_mois_4' => '@j@ d\'abriau',
'date_de_mois_5' => '@j@ de mai',
'date_de_mois_6' => '@j@ de junh',
'date_de_mois_7' => '@j@ de julh',
'date_de_mois_8' => '@j@ d\'aost',
'date_de_mois_9' => '@j@ de setembre',
'date_demain' => 'deman',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ a @heure@',
'date_fmt_jour_mois' => '@jourmois@',
'date_fmt_jour_mois_annee' => '@jourmois@ de @annee@',
'date_fmt_mois_annee' => '@nommois@ de @annee@',
'date_fmt_nomjour_date' => 'lo @nomjour@ @date@',
'date_heures' => 'oras',
'date_hier' => 'i&egrave;r',
'date_il_y_a' => 'fai @delai@',
'date_jnum1' => '1r',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'dimenge',
'date_jour_1_abbr' => 'dim.', # NEW
'date_jour_1_initiale' => 'd.', # NEW
'date_jour_2' => 'diluns',
'date_jour_2_abbr' => 'lun.', # NEW
'date_jour_2_initiale' => 'l.', # NEW
'date_jour_3' => 'dimars',
'date_jour_3_abbr' => 'mar.', # NEW
'date_jour_3_initiale' => 'm.', # NEW
'date_jour_4' => 'dim&egrave;cres',
'date_jour_4_abbr' => 'mer.', # NEW
'date_jour_4_initiale' => 'm.', # NEW
'date_jour_5' => 'dij&ograve;us',
'date_jour_5_abbr' => 'jeu.', # NEW
'date_jour_5_initiale' => 'j.', # NEW
'date_jour_6' => 'divendres',
'date_jour_6_abbr' => 'ven.', # NEW
'date_jour_6_initiale' => 'v.', # NEW
'date_jour_7' => 'dissabte',
'date_jour_7_abbr' => 'sam.', # NEW
'date_jour_7_initiale' => 's.', # NEW
'date_jours' => 'jorns',
'date_minutes' => 'minutas',
'date_mois' => 'mes',
'date_mois_1' => 'girv&egrave;ir',
'date_mois_10' => 'oct&ograve;bre',
'date_mois_11' => 'novembre',
'date_mois_12' => 'decembre',
'date_mois_2' => 'feur&egrave;ir',
'date_mois_3' => 'mar&ccedil;',
'date_mois_4' => 'abriau',
'date_mois_5' => 'mai',
'date_mois_6' => 'junh',
'date_mois_7' => 'julh',
'date_mois_8' => 'aost',
'date_mois_9' => 'setembre',
'date_saison_1' => 'iv&egrave;rn',
'date_saison_2' => 'prima',
'date_saison_3' => 'estiu',
'date_saison_4' => 'endarr&egrave;ir',
'date_secondes' => 'secondes', # NEW
'date_semaines' => 'setmana(s)',
'date_un_mois' => 'mois', # NEW
'date_une_heure' => 'heure', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'seconde', # NEW
'date_une_semaine' => 'semaine', # NEW
'dirs_commencer' => 'per comen&ccedil;ar vertad&egrave;irament l\'installacion',
'dirs_preliminaire' => 'Preliminar: <b>Reglar los dreits d\'acc&egrave;s</b>',
'dirs_probleme_droits' => 'Probl&egrave;ma de dreits d\'acc&egrave;s',
'dirs_repertoires_absents' => '<b>S\'es pas trobat los repert&ograve;ris seguents: <ul>@bad_dirs@.</ul> </b>
  <p>Se p&ograve;t que venha d\'un probl&egrave;ma de majusculas o minusculas mau mesas.
  Verificatz que las minusculas e majusculas d\'aqueles repert&ograve;ris correspondan be amb qu&ograve; afichat
  &ccedil;ai sobre; s\'es pas lo cas, tornatz nommar los repert&ograve;ris amb v&ograve;stre logiciau FTP en corregir l\'error.
  </p><p>Un c&ograve;p qu\'auretz fait aqu&ograve;, poiretz </p>',
'dirs_repertoires_suivants' => '<b>Los repert&ograve;ris seguents son pas accessibles en escritura: <ul>@bad_dirs@.</ul> </b>
  <p>Per adobar aqu&ograve;, utilizatz v&ograve;stre client FTP a fin de reglar los dreits d\'acc&egrave;s de chascun
  d\'aqueles repert&ograve;ris. La guida d\'installacion explica en detalh coss&iacute; chau procedir.
  </p><p>Entre qu\'auretz faita aquela manipulacion, poiretz </p>',
'double_occurrence' => 'Double occurrence de @balise@', # NEW

// E
'en_cours' => 'en cours', # NEW
'entree_dimensions' => 'Dimensions:',
'entree_titre_document' => 'T&iacute;tol dau document:',
'entree_titre_image' => 'T&iacute;tol de l\'imatge:',
'envoi_via_le_site' => 'Mandad&iacute;s amb lo biais dau sit web',
'erreur' => 'Erreur', # NEW
'erreur_balise_non_fermee' => 'derni&egrave;re balise non referm&eacute;e :', # NEW
'erreur_texte' => 'erreur(s)', # NEW
'etape' => '&Eacute;tape', # NEW

// F
'fichier_introuvable' => 'S\'es pas pogut trobar lo fich&egrave;ir @fichier@.',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'S&egrave;tz ja inscrit(a).',
'form_email_non_valide' => 'V&ograve;stra adrei&ccedil;a e-mail es pas valida.',
'form_forum_access_refuse' => 'Pod&egrave;tz pas mai accedir v&egrave;rs aquel sit.',
'form_forum_bonjour' => 'Bonjorn @nom@,',
'form_forum_email_deja_enregistre' => 'Aquela adrei&ccedil;a e-mail ja z-es registrada, adoncas pod&egrave;tz utilizar v&ograve;stre mot de santa Clara costum&egrave;ir.',
'form_forum_identifiant_mail' => 'Vos av&egrave;m mandat v&ograve;stre identificant nov&egrave;l per e-mail.',
'form_forum_identifiants' => 'Identificants personaus',
'form_forum_indiquer_nom_email' => 'Indicatz aqu&iacute; v&ograve;stre nom e v&ograve;stra adrei&ccedil;a e-mail. V&ograve;stre identificant personau arribar&aacute; regde, per e-mail.',
'form_forum_login' => 'login:',
'form_forum_message_auto' => '(quo es un messatge automatic)',
'form_forum_pass' => 'mot de santa Clara:',
'form_forum_probleme_mail' => 'Probl&egrave;ma d\'e-mail: se p&ograve;t pas mandar l\'identificant.',
'form_forum_voici1' => 'Veiqu&iacute; v&ograve;stres identificants per poder participar aus forums
dau sit "@nom_site_spip@" (@adresse_site@):',
'form_forum_voici2' => 'Veiqu&iacute; v&ograve;stres identificants per prepausar d\'articles 
 sobre lo sit "@nom_site_spip@" (@adresse_login@):',
'form_indiquer_email' => 'Volhatz indicar v&ograve;stra adrei&ccedil;a e-mail.',
'form_indiquer_nom' => 'Volhatz indicar v&ograve;stre nom.',
'form_indiquer_nom_site' => 'Volhatz indicar lo nom de v&ograve;stre sit.',
'form_pet_adresse_site' => 'Adrei&ccedil;a de v&ograve;stre sit',
'form_pet_aucune_signature' => 'Gran de signatura correspond pas a aquel c&ograve;de...',
'form_pet_confirmation' => 'Volhatz confirmar v&ograve;stra signatura:',
'form_pet_deja_enregistre' => 'Ja aquel sit es registrat',
'form_pet_deja_signe' => 'Av&egrave;tz ja signat aquel t&egrave;xt.',
'form_pet_envoi_mail_confirmation' => 'Ara recebretz un e-mail de confirmacion. Per validar v&ograve;stra signatura, chau vesitar l\'adrei&ccedil;a web men&ccedil;onada per aqueste corr&egrave;ir.', # MODIF
'form_pet_mail_confirmation' => 'Bonjorn,

av&egrave;tz demandat de signar la peticion:
@titre@.

Av&egrave;tz fornidas las informacions seguentas:
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@


IMPORTANT...
Per validar v&ograve;stra signatura, suf&iacute;s de vos connectar a 
 l\'adrei&ccedil;a &ccedil;ai sos (senon se rebofar&aacute;
v&ograve;stra demanda): 
    @url@


Merc&eacute;s per v&ograve;stra participacion
',
'form_pet_message_commentaire' => 'Un messatge, una remarca?',
'form_pet_nom_site2' => 'Nom de v&ograve;stre sit web',
'form_pet_probleme_liens' => 'Veuillez reprendre votre message en supprimant les liens hypertexte.', # NEW
'form_pet_probleme_technique' => 'Probl&egrave;ma tecnic, las signaturas son tempor&agrave;riament \'restadas.',
'form_pet_signature_pasprise' => 'V&ograve;stra signatura es pas presa en compte.',
'form_pet_signature_validee' => 'V&ograve;stra signatura es validada. Merc&eacute;s!',
'form_pet_site_deja_enregistre' => 'Ja aquel sit es registrat',
'form_pet_url_invalide' => 'L\'URL qu\'av&egrave;tz indicada es pas valida.',
'form_pet_votre_email' => 'V&ograve;stra adrei&ccedil;a e-mail',
'form_pet_votre_nom' => 'V&ograve;stre nom o pseudonim',
'form_pet_votre_site' => 'Se ten&egrave;tz un sit, o pod&egrave;tz marcar &ccedil;ai sos',
'form_prop_confirmer_envoi' => 'Confirmar l\'enviament',
'form_prop_description' => 'Descripcion/comentari',
'form_prop_enregistre' => 'V&ograve;stra proposicion es plan registrada, apareisser&aacute; en linha entre que los responsables dau sit l\'aur&aacute;n validada .',
'form_prop_envoyer' => 'Mandar un messatge',
'form_prop_indiquer_email' => 'Volhatz indicar una adrei&ccedil;a e-mail valida',
'form_prop_indiquer_nom_site' => 'Volhatz indicar lo nom dau sit.',
'form_prop_indiquer_sujet' => 'Volhatz indicar un subj&egrave;cte',
'form_prop_message_envoye' => 'Messatge mandat',
'form_prop_nom_site' => 'Nom dau sit',
'form_prop_non_enregistre' => 'V&ograve;stra proposicion es pas estada registrada.',
'form_prop_sujet' => 'Subj&egrave;cte',
'form_prop_url_site' => 'Adrei&ccedil;a (URL) dau sit',
'forum_acces_refuse' => 'Pod&egrave;tz pas mai accedir v&egrave;rs aqueles forums.',
'forum_attention_dix_caracteres' => '<b>Atencion!</b> v&ograve;stre messatge deu t&eacute;ner aumens d&egrave;tz caract&egrave;rs.',
'forum_attention_trois_caracteres' => '<b>Atencion!</b> v&ograve;stre t&iacute;tol deu t&eacute;ner aumens tres caract&egrave;rs.',
'forum_attention_trop_caracteres' => '<b>Attention&nbsp;!</b> votre message est trop long (@compte@ caract&egrave;res)&nbsp;: pour pouvoir &ecirc;tre enregistr&eacute;, il ne doit pas d&eacute;passer @max@ caract&egrave;res.', # NEW
'forum_avez_selectionne' => 'Av&egrave;tz seleccionat:',
'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aic&iacute;</a> per contunhar.',
'forum_forum' => 'forum',
'forum_info_modere' => 'Aqueste forum es moderat a pri&ograve;ri: v&ograve;stra contribucion pareisser&aacute; pas qu\'apr&egrave;s qu\'un administrator dau sit l\'aja validada.',
'forum_lien_hyper' => '<b>Liam ipert&egrave;xt</b> (opcionau)',
'forum_message_definitif' => 'Messatge definitiu : mandar au sit',
'forum_message_trop_long' => 'V&ograve;stre messatge es tr&ograve;p long. La lonjor maximala es de 20&nbsp;000 caract&egrave;rs.',
'forum_ne_repondez_pas' => 'Respondatz pas a aquel e-mail mas per lo forum a l\'adrei&ccedil;a seguenta: ',
'forum_non_inscrit' => 'Si&aacute; s&egrave;tz pas inscrit(a), si&aacute; av&egrave;tz fait una error d\'adrei&ccedil;a o de mot de santa Clara. ',
'forum_page_url' => '(se v&ograve;stre messatge se refer&iacute;s a un article publicat per lo web, o a una pagina que baile mai d\'informacions, volhatz marcar &ccedil;ai sos lo t&iacute;tol de la pagina e son adrei&ccedil;a URL.)',
'forum_par_auteur' => 'per @auteur@',
'forum_poste_par' => 'Messatge poste@parauteur@ que fai seguda a v&ograve;stre article.',
'forum_probleme_database' => 'Probl&egrave;ma de basa de donadas, v&ograve;stre messatge s\'es pas registrat.',
'forum_qui_etes_vous' => '<b>Quau s&egrave;tz?</b> (opcionau)',
'forum_texte' => 'T&egrave;xt de v&ograve;stre messatge:',
'forum_titre' => 'T&iacute;tol:',
'forum_titre_erreur' => 'Error...',
'forum_url' => 'URL:',
'forum_valider' => 'Validar aquela chausida',
'forum_voir_avant' => 'Veire lo messatge avans de lo mandar',
'forum_votre_email' => 'V&ograve;stra adrei&ccedil;a e-mail:',
'forum_votre_nom' => 'V&ograve;stre nom (o pseudonim):',
'forum_vous_enregistrer' => 'Per participar a
  aquel forum, d\'en prim&egrave;ir vos chau registrar. Merc&eacute;s
  de marcar &ccedil;ai sos l\'identificant personau qu\'av&egrave;tz recebut.
 Se s&egrave;tz pas registrat/ada, av&egrave;tz de',
'forum_vous_inscrire' => 'vos inscriure ',

// I
'ical_texte_rss_articles' => 'Lo fich&egrave;ir "backend" daus articles d\'aqueste sit se tr&ograve;ba a l\'adrei&ccedil;a:',
'ical_texte_rss_articles2' => 'Aitanben pod&egrave;tz obt&eacute;ner de fich&egrave;irs "backend" per los articles de chasca rubrica dau sit:',
'ical_texte_rss_breves' => 'Existisson mai que d\'un fich&egrave;ir contenent las br&egrave;vas dau sit. En precisar un num&egrave;ro de rubrica,  obtendretz mas las br&egrave;vas de la rubrica aquela.',
'icone_a_suivre' => 'De s&egrave;gre',
'icone_admin_site' => 'Administracion dau sit',
'icone_agenda' => 'Agenda e messatjari&aacute;',
'icone_aide_ligne' => 'Ajuda',
'icone_articles' => 'Articles',
'icone_auteurs' => 'Autors',
'icone_breves' => 'Br&egrave;vas',
'icone_brouteur' => 'Navigacion rapida',
'icone_configuration_site' => 'Configuracion',
'icone_configurer_site' => 'Configurar v&ograve;stre sit',
'icone_creer_nouvel_auteur' => 'Crear un autor nu&ograve;u',
'icone_creer_rubrique' => 'Crear una rubrica',
'icone_creer_sous_rubrique' => 'Crear una sosrubrica',
'icone_deconnecter' => 'Se desconnectar',
'icone_discussions' => 'Discussions',
'icone_doc_rubrique' => 'Documents de las rubricas',
'icone_ecrire_article' => 'Escriure un article nu&ograve;u',
'icone_edition_site' => 'Edicion',
'icone_forum_administrateur' => 'Forum daus administrators',
'icone_forum_suivi' => 'Segut daus forums',
'icone_gestion_langues' => 'Gestion de las lengas',
'icone_informations_personnelles' => 'Informacions personalas',
'icone_interface_complet' => 'Interf&agrave;cia completa',
'icone_interface_simple' => 'Interf&agrave;cia simplificada',
'icone_maintenance_site' => 'Mantenen&ccedil;a dau sit',
'icone_messagerie_personnelle' => 'Messatjari&aacute; personala',
'icone_mots_cles' => 'Mots claus',
'icone_nouvelle_breve' => 'Escriure una br&egrave;va nu&ograve;va',
'icone_repartition_actuelle' => 'Afichar la reparticion actuala',
'icone_repartition_debut' => 'Afichar la reparticion dempu&egrave;i l\'emprim&egrave;ir',
'icone_repartition_visites' => 'Reparticion de las vesitas',
'icone_rubriques' => 'Rubricas',
'icone_sauver_site' => 'Sauvagarda dau sit',
'icone_site_entier' => 'Tot lo sit ',
'icone_sites_references' => 'Sits referenciats',
'icone_statistiques' => 'Estadisticas dau sit',
'icone_statistiques_visites' => 'Estadisticas',
'icone_suivi_activite' => 'S&egrave;gre la vida dau sit',
'icone_suivi_actualite' => 'Evolucion dau sit',
'icone_suivi_forums' => 'S&egrave;gre/gerir los forums',
'icone_suivi_pettions' => 'S&egrave;gre/gerir las peticions',
'icone_suivi_revisions' => 'Modificacions daus articles',
'icone_supprimer_document' => 'Suprimir aquel document',
'icone_supprimer_image' => 'Suprimir aquel imatge',
'icone_supprimer_message' => 'Suprimir aquel messatge',
'icone_tous_articles' => 'Totes v&ograve;stres articles ',
'icone_tous_auteur' => 'Totes los autors ',
'icone_valider_message' => 'Validar aquel messatge',
'icone_visiter_site' => 'Vesitar',
'icone_voir_en_ligne' => 'Veire en linha',
'image_tourner_180' => 'Rotacion 180&deg;',
'image_tourner_droite' => 'Rotacion 90&deg; v&egrave;rs la dreita',
'image_tourner_gauche' => 'Rotacion 90&deg; v&egrave;rs la man&ccedil;a',
'img_indisponible' => 'imatge indisponible',
'impossible' => 'impossible', # NEW
'info_a_suivre' => 'DE S&Egrave;GRE>>',
'info_a_valider' => '[de validar]',
'info_acces_interdit' => 'Acc&egrave;s pro&iuml;bit',
'info_acces_refuse' => 'Acc&egrave;s refusat',
'info_action' => 'Accion: @action@',
'info_administrer_rubriques' => 'Pod&egrave;tz administrar aquela rubrica e sas sosrubricas',
'info_adresse_non_indiquee' => 'Av&egrave;tz pas indicat l\'adrei&ccedil;a de testar!',
'info_aide' => 'AJUDA:',
'info_ajouter_mot' => 'Apondre aquel mot',
'info_annonce' => 'ANONCI',
'info_annonces_generales' => 'Anoncis generaus:',
'info_article_propose' => 'Article prepausat',
'info_article_publie' => 'Article publicat',
'info_article_redaction' => 'Article en cors de redaccion',
'info_article_refuse' => 'Article refusat',
'info_article_supprime' => 'Article suprimit',
'info_articles' => 'Articles',
'info_articles_a_valider' => 'Los articles de validar',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Articles prepausats',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'autor(s)',
'info_authentification_ftp' => 'autentificacion (per FTP).',
'info_bloquer_lien' => 'Blocar aquel liam',
'info_breves_02' => 'Br&egrave;vas',
'info_breves_2' => 'br&egrave;vas',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Br&egrave;vas de validar',
'info_connexion_refusee' => 'Connexion refusada',
'info_contact_developpeur' => 'Volhatz contactar un desvolopaire.',
'info_contenance' => 'Aquel sit conten:',
'info_contribution' => 'Contribucions de forum',
'info_copyright' => '@spip@ z-es un logiciau liure distribuit @lien_gpl@.',
'info_copyright_doc' => 'Per mai d\'informacions, veire lo sit <a href="@spipnet@">http://www.spip.net/oc</a>.', # MODIF
'info_copyright_gpl' => 'sos lic&eacute;ncia GPL',
'info_cours_edition' => 'V&ograve;stres articles en cors de redaccion',
'info_creer_repertoire' => 'Volhatz crear un fich&egrave;ir o un repert&ograve;ri nommat',
'info_creer_repertoire_2' => 'endins lo sosrepert&ograve;ri   <b>@repertoire@</b>, pu&egrave;i:',
'info_creer_vignette' => 'creacion automatica de la vinheta',
'info_deplier' => 'Desplejar',
'info_descriptif_nombre' => 'descriptiu(s):',
'info_description' => 'Descripcion:',
'info_description_2' => 'Descripcion:',
'info_dimension' => 'Dimensions:',
'info_document' => 'Document ',
'info_document_indisponible' => 'Ce document n\'est pas disponible', # NEW
'info_documents' => 'Documents',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP permet d\'eschamjar de messatges e de constituir de forums privats de discussion entre los participants dau sit. Pod&egrave;tz activar o desactivar aquela foncionalitat.',
'info_ecire_message_prive' => 'Escriure un messatge privat',
'info_email_invalide' => 'Adrei&ccedil;a e-mail invalida',
'info_en_cours_validation' => 'V&ograve;stres articles en cors de redaccion',
'info_en_ligne' => 'Ara en linha:',
'info_envoyer_message_prive' => 'Mandar un messatge privat a aquel autor',
'info_erreur_requete' => 'Error dins la requ&egrave;sta',
'info_erreur_squelette2' => 'Ges d\'esqueleta <b>@fichier@</b> z-es disponibla...',
'info_erreur_systeme' => 'Error sist&egrave;ma (errno @errsys@)',
'info_erreur_systeme2' => 'Lo disc dur es benl&egrave;u plen, o la basa de donadas degalhada. <br />
 <font color=\'red\'>\'Sajatz de <a href=\'@script@\'>reparar la basa</a>,
 o contactatz v&ograve;stre auberjador.</font>',
'info_fini' => 'Quo es \'chabat!',
'info_format_image' => 'Formats d\'imatges que se p&ograve;don utilizar per crear de vinhetas: @gd_formats@.',
'info_format_non_defini' => 'format non definit',
'info_grand_ecran' => 'Ecran grand ',
'info_image_aide' => 'AJUDA',
'info_image_process_titre' => 'Met&ograve;de de fabricacion de las vinhetas',
'info_impossible_lire_page' => '<b>Error!</b> Impossible de legir la pagina <tt><html>@test_proxy@</html></tt> a trav&egrave;rs dau proxy <tt>',
'info_inclusion_directe' => 'Inclusion dir&egrave;cta:',
'info_inclusion_vignette' => 'Inclusion de la vinheta:',
'info_installation_systeme_publication' => 'Installacion dau sist&egrave;ma de publicacion...',
'info_installer_documents' => 'Pod&egrave;tz installar automaticament totes los documents contenguts dins lo repert&ograve;ri @upload@.',
'info_installer_ftp' => 'Coma administrator, pod&egrave;tz installar (per FTP) de fich&egrave;irs dins lo dors&egrave;ir @upload@,  pu&egrave;i los  seleccionar dir&egrave;ctament aic&iacute;.',
'info_installer_images' => 'Pod&egrave;tz installar d\'imatges aus formats JPEG, GIF e PNG.',
'info_installer_images_dossier' => 'Installar d\'imatges dins lo dors&egrave;ir @upload@ per los poder seleccionar aic&iacute;.',
'info_installer_tous_documents' => 'Installar totes los documents ',
'info_interface_complete' => 'Interf&agrave;cia completa',
'info_interface_simple' => 'Interf&agrave;cia simplificada',
'info_joindre_document_article' => 'Pod&egrave;tz j&oacute;nher a aquel article de documents de la mena de',
'info_joindre_document_rubrique' => 'Pod&egrave;tz apondre a aquela rubrica de documents de la mena de',
'info_joindre_documents_article' => 'Pod&egrave;tz j&oacute;nher a aquel article de documents de la mena de:',
'info_l_article' => 'l\'article',
'info_la_breve' => 'la br&egrave;va',
'info_la_rubrique' => 'la rubrica',
'info_langue_principale' => 'Lenga majorala dau sit',
'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ pix&egrave;ls',
'info_les_auteurs_1' => 'per @les_auteurs@ ',
'info_logo_format_interdit' => 'Los l&ograve;gos de formats @formats@ son sols autorizats.',
'info_logo_max_poids' => 'Los l&ograve;gos an de far mens de @maxi@ (aqueste fich&egrave;ir fai @actuel@).',
'info_logo_max_taille' => 'Los l&ograve;gos an de far mens de @maxi@ (aqueste fich&egrave;ir fai @actuel@).',
'info_mail_fournisseur' => 'vos@fornidor.com',
'info_message_2' => 'MESSATGE',
'info_message_supprime' => 'MESSATGE SUPRIMIT',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Data de mesa en linha:',
'info_modification_parametres_securite' => 'modificacions daus param&egrave;tres de seguretat',
'info_mois_courant' => 'Dins lo corrent dau mes:',
'info_mot_cle_ajoute' => 'S\'es apondut lo mot clau seguent a ',
'info_multi_herit' => 'Lenga predefinida',
'info_multi_langues_soulignees' => 'Las <u>lengas solinhadas</u> benef&iacute;cian d\'una revirada de totes los t&egrave;xts de l\'interf&agrave;cia. Se seleccionatz aquelas lengas, gr&ograve;s d\'elements dau sit public (datas, formularis) se revirar&aacute;n automaticament. Per las lengas non solinhadas, aqueles elements apareisser&aacute;n dins la lenga principala dau sit.',
'info_multilinguisme' => 'Multiling&uuml;isme',
'info_nom_non_utilisateurs_connectes' => 'V&ograve;stre nom apareis pas dins la t&egrave;ira daus utilizaires connectats.',
'info_nom_utilisateurs_connectes' => 'V&ograve;stre nom apareis dins la t&egrave;ira daus utilizaires connectats.',
'info_nombre_en_ligne' => 'Ara en linha:',
'info_non_resultat' => 'Ges de resultat per "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Utilizatz pas la messatjari&aacute; int&egrave;rna d\'aquel sit.',
'info_nouveau_message' => 'AV&Egrave;TZ UN MESSATGE NU&Ograve;U',
'info_nouveaux_messages' => 'AV&Egrave;TZ @total_messages@ MESSATGES NU&Ograve;US',
'info_numero_abbreviation' => 'N&deg;&nbsp;',
'info_obligatoire' => 'Cette information est obligatoire', # NEW
'info_panne_site_syndique' => 'Sit sindicat en pana',
'info_pense_bete' => 'MEMENTO',
'info_petit_ecran' => 'Ecran petit',
'info_petition_close' => 'P&eacute;tition close', # NEW
'info_pixels' => 'pix&egrave;ls',
'info_plusieurs_mots_trouves' => 'Mai d\'un mot clau trobat per "@cherche_mot@"&nbsp;:',
'info_popularite_5' => 'popularitat:',
'info_portfolio' => 'P&ograve;rtf&ograve;lio',
'info_portfolio_automatique' => 'P&ograve;rtf&ograve;lio automatic:',
'info_premier_resultat' => '[@debut_limit@ prim&egrave;irs resultats de @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ prim&egrave;irs resultats de @total@]',
'info_probleme_grave' => 'probl&egrave;ma de',
'info_propose_1' => '[@nom_site_spip@] Prepausa: @titre@',
'info_propose_2' => 'Article prepausat
---------------',
'info_propose_3' => 'L\'article "@titre@" z-es prepausat a la publicacion.',
'info_propose_4' => 'Vos convidam a lo venir consultar e a bailar v&ograve;stre vejaire',
'info_propose_5' => 'dins lo forum que li es estachat. Z-es disponible a l\'adrei&ccedil;a:',
'info_publie_01' => 'L\'article "@titre@" z-es estat validat per @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] PUBLICA: @titre@',
'info_publie_2' => 'Article publicat
--------------',
'info_rechercher' => 'Cerchar',
'info_rechercher_02' => 'Cerchar:',
'info_remplacer_vignette' => 'Rempla&ccedil;ar la vinheta predefinida per un l&ograve;go personalizat:',
'info_retablir_lien' => 'Restablir aquel liam',
'info_retirer_mot' => 'Quitar aquel mot',
'info_retirer_mots' => 'Quitar totes los mots ',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'sens t&iacute;tol',
'info_selectionner_fichier' => 'Pod&egrave;tz seleccionar un fich&egrave;ir dau dors&egrave;ir @upload@',
'info_selectionner_fichier_2' => 'Seleccionar un fich&egrave;ir:',
'info_signature_supprimee' => 'Signature supprim&eacute;e', # NEW
'info_signature_supprimee_erreur' => 'Erreur&nbsp;: ce code de suppression ne correspond a aucune signature', # NEW
'info_site_attente' => 'Sit web en ap&egrave;ita de validacion',
'info_site_reference' => 'Sit referenciat en linha',
'info_site_refuse' => 'Sit web refusat',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Referenciar un sit',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'suprimir la vinheta',
'info_symbole_bleu' => 'Lo simb&egrave;u <b>blau</b> marca un <b>memento</b>: qu&ograve; v&ograve;u dire un messatge per v&ograve;stre usatge personau.',
'info_symbole_jaune' => 'Lo simb&egrave;u <b>jaune</b> marca un <b>anonci per totes los redactors </b>: los administrators lo p&ograve;don modificar, chasque redactor lo p&ograve;t veire.',
'info_symbole_vert' => 'Lo simb&egrave;u <b>verd</b> marca los <b>messatges eschamjats amb d\'autres utilizaires</b> dau sit.',
'info_syndication' => 'sindicacion:',
'info_syndication_articles' => 'article(s)',
'info_telecharger' => 'Telecharjar a partir de v&ograve;stre ordenador:',
'info_telecharger_nouveau_logo' => 'Telecharjar un l&ograve;go nu&ograve;u:',
'info_telecharger_ordinateur' => 'Telecharjar a partir de v&ograve;stre ordenador:',
'info_tous_resultats_enregistres' => '[totes los resultats son registrats]',
'info_tout_afficher' => 'Afichar tot',
'info_travaux_texte' => 'Aquel sit es pas encara configurat. Tornatz mai tard...',
'info_travaux_titre' => 'Sit en &ograve;bras',
'info_trop_resultat' => 'Tr&ograve;p de resultats per "@cherche_mot@"; volhatz afinar la rec&egrave;rcha.',
'info_utilisation_messagerie_interne' => 'Utilizatz la messatjari&aacute; int&egrave;rna d\'aquel sit.',
'info_valider_lien' => 'validar aquel liam',
'info_verifier_image' => ', volhatz verificar que los imatges se si&aacute;n be transferits.',
'info_vignette_defaut' => 'Vinheta predefinida',
'info_vignette_personnalisee' => 'Vinheta personalizada',
'info_visite' => 'vesita:',
'info_visites' => 'vesitas:',
'info_vos_rendez_vous' => 'V&ograve;stres rend&egrave;tz-vos venents',
'info_zoom' => 'zoom',
'infos_vos_pense_bete' => 'V&ograve;stres mementos', # MODIF
'item_breve_proposee' => 'Br&egrave;va prepausada',

// L
'lien_afficher_icones_seuls' => 'Afichar mas las ic&ograve;nas',
'lien_afficher_texte_icones' => 'Afichar las ic&ograve;nas e lo t&egrave;xt',
'lien_afficher_texte_seul' => 'Afichar mas lo t&egrave;xt',
'lien_liberer' => 'liberar',
'lien_liberer_tous' => 'liberar aqueles articles',
'lien_nouvea_pense_bete' => 'MEMENTO NU&Ograve;U',
'lien_nouveau_message' => 'MESSATGE NU&Ograve;U',
'lien_nouvelle_annonce' => 'ANONCI NOV&Egrave;L',
'lien_petitions' => 'PETICION',
'lien_popularite' => 'popularitat: @popularite@%',
'lien_racine_site' => 'RAI&Ccedil; DAU SIT',
'lien_reessayer' => 'tornar assajar',
'lien_repondre_message' => 'Respondre a aquel messatge',
'lien_supprimer' => 'suprimir',
'lien_tout_afficher' => 'Afichar tot',
'lien_visite_site' => 'vesitar aquel sit',
'lien_visites' => '@visites@&nbsp;vesitas',
'lien_voir_auteur' => 'Veire aquel autor',
'ligne' => 'Ligne', # NEW
'login' => 'Connexion', # NEW
'login_acces_prive' => 'acc&egrave;s a l\'espaci privat',
'login_autre_identifiant' => 'se connectar amb un autre identificant',
'login_cookie_accepte' => 'Volhatz configurar v&ograve;stre navigador per que los acc&egrave;pte (per lo mens amb aquel sit).',
'login_cookie_oblige' => 'Per vos identificar d\'una man&egrave;ira segura sus aqueste sit, vos chau acceptar los cookies.',
'login_deconnexion_ok' => 'S&egrave;tz desconnectat/ada.',
'login_erreur_pass' => 'Error de mot de santa Clara.',
'login_espace_prive' => 'espaci privat',
'login_identifiant_inconnu' => 'L\'identificant &laquo;@login@&raquo; z-es inconegut.',
'login_login' => 'Login:',
'login_login2' => 'Login (identificant de connexion au sit):',
'login_login_pass_incorrect' => '(Login o mot de santa Clara incorr&egrave;cte.)',
'login_motpasseoublie' => 'mot&nbsp;de&nbsp;santa&nbsp;Clara&nbsp;oblidat?',
'login_non_securise' => 'Atencion, aquel formulari z-es pas securizat.
    Se vol&egrave;tz pas que v&ograve;stre mot de santa Clara si&aacute;
   interceptat sobre lo ret, volhatz activar Javascript 
   dins v&ograve;stre navigador e',
'login_nouvelle_tentative' => 'nov&egrave;l assai',
'login_par_ici' => 'S&egrave;tz registrat/ada... per aqu&iacute;...',
'login_pass2' => 'Mot de santa Clara:',
'login_preferez_refuser' => '<b>Se vos agrada mai de refusar los cookies</b>, un autre met&ograve;de de connexion (mens securizat) z-es a v&ograve;stra disposicion:',
'login_recharger' => 'tornar charjar aquela pagina',
'login_rester_identifie' => 'Demorar identificat quauques jorns',
'login_retour_public' => 'Tornar au sit public',
'login_retour_site' => 'Tornar au sit public',
'login_retoursitepublic' => 'tornar&nbsp;au&nbsp;sit&nbsp;public',
'login_sans_cookiie' => 'Identificacion sens cookie',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 's\'inscriure',
'login_test_navigateur' => 'Assai navigador/tornar&nbsp;connectar',
'login_verifiez_navigateur' => '(pasmens verificatz que v&ograve;stre navigador aja pas servat v&ograve;stre mot de santa Clara en mem&ograve;ria...)',

// M
'masquer_colonne' => 'Masquer cette colonne', # NEW
'masquer_trad' => 'masquer les traductions', # NEW
'module_fichiers_langues' => 'Fich&egrave;irs de lenga',

// N
'navigateur_pas_redirige' => 'Se v&ograve;stre navigador z-es pas redirigit, clicatz aic&iacute; per contunhar.',
'numero' => 'Num&eacute;ro', # NEW

// O
'occurence' => 'Occurrence', # NEW
'onglet_affacer_base' => 'Esfa&ccedil;ar la basa',
'onglet_auteur' => 'L\'autor',
'onglet_contenu_site' => 'Contengut dau sit',
'onglet_evolution_visite_mod' => 'Evolucion',
'onglet_fonctions_avances' => 'Foncions avan&ccedil;adas',
'onglet_informations_personnelles' => 'Informacions personalas',
'onglet_interactivite' => 'Interactivitat',
'onglet_messagerie' => 'Messatjari&aacute;',
'onglet_messages_internes' => 'Messatges int&egrave;rnes',
'onglet_messages_publics' => 'Messatges publics',
'onglet_messages_vide' => 'Messatges sens t&egrave;xt',
'onglet_origine_visites' => 'Origina de las vesitas',
'onglet_repartition_debut' => 'dempu&egrave;i l\'emprim&egrave;ir',
'onglet_repartition_lang' => 'Reparticion per lengas',
'onglet_repartition_rubrique' => 'Reparticion per rubricas',
'onglet_save_restaur_base' => 'Sauvagardar/restaurar la basa',
'onglet_vider_cache' => 'Voidar l\'escondedor',

// P
'pass_choix_pass' => 'Volhatz chausir v&ograve;stre mot de santa Clara nov&egrave;l:',
'pass_erreur' => 'Error',
'pass_erreur_acces_refuse' => '<b>Error :</b> pod&egrave;tz pas mai accedir a aquel sit.',
'pass_erreur_code_inconnu' => '<b>Error:</b> aquel c&ograve;de correspond pas a ges de vesitaire que pu&egrave;scha accedir a aquel sit.',
'pass_erreur_non_enregistre' => '<b>Error:</b> l\'adrei&ccedil;a <tt>@email_oubli@</tt> z-es pas registrada sus aquel sit.',
'pass_erreur_non_valide' => '<b>Error:</b> aquel e-mail <tt>@email_oubli@</tt> z-es pas valid!',
'pass_erreur_probleme_technique' => '<b>Error:</b> pr\'amor d\'un probl&egrave;ma tecnic, l\'e-mail se p&ograve;t pas mandar. ',
'pass_espace_prive_bla' => 'L\'espaci privat d\'aqueste sit es badat v&egrave;rs los
  vesitaires que se son inscrits. Un c&ograve;p registrat/ada,
  poiretz consultar los articles en cors de redaccion,
  prepausar d\'articles nov&egrave;ls e participar a totes los forums.',
'pass_forum_bla' => 'Av&egrave;tz demandat d\'intervenir dins un forum
  reservat aus vesitaires registrats.',
'pass_indiquez_cidessous' => 'Marcatz &ccedil;ai sos l\'adrei&ccedil;a e-mail ont
 vos registr&egrave;retz lo c&ograve;p passat. 
   Recebretz un e-mail que vos bailar&aacute; la man&egrave;ira de 
    tornar trobar v&ograve;stre acc&egrave;s.',
'pass_mail_passcookie' => '(quo es un messatge automatic)
Per tornar trobar v&ograve;stre acc&egrave;s au sit
@nom_site_spip@ (@adresse_site@)

Volhatz anar a l\'adrei&ccedil;a seguenta:

    @sendcookie@

Aladonc poiretz entrar un mot de santa Clara nov&egrave;l
e vos tornar connectar au sit.

',
'pass_mot_oublie' => 'Mot de santa Clara eissubliat',
'pass_nouveau_enregistre' => 'V&ograve;stre mot de santa Clara nov&egrave;l z-es estat registrat.',
'pass_nouveau_pass' => 'Mot de santa Clara nov&egrave;l',
'pass_ok' => 'Consent',
'pass_oubli_mot' => 'Mot de santa Clara eissubliat',
'pass_quitter_fenetre' => 'Quitar aquesta fen&egrave;stra ',
'pass_rappel_login' => 'Remembran&ccedil;a: v&ograve;stre identificant (login) z-es &laquo;@login@&raquo;.',
'pass_recevoir_mail' => 'Recebretz un e-mail que vos explicar&aacute; coss&iacute; tornar trobar v&ograve;stre acc&egrave;s au sit.',
'pass_retour_public' => 'Tornar au sit public',
'pass_rien_a_faire_ici' => 'Ren a faire aic&iacute;.',
'pass_vousinscrire' => 'S\'inscriure sus aqueste sit',
'precedent' => 'precedent',
'previsualisation' => 'Previsualizacion',
'previsualiser' => 'Previsualizar',

// R
'retour' => 'Retour', # NEW

// S
'spip_conforme_dtd' => 'SPIP consid&egrave;re ce document comme conforme &agrave; son DOCTYPE :', # NEW
'squelette' => 'squelette', # NEW
'squelette_inclus_ligne' => 'squelette inclus, ligne', # NEW
'squelette_ligne' => 'squelette, ligne', # NEW
'stats_visites_et_popularite' => '@visites@ vesitas; popularitat: @popularite@',
'suivant' => 'seguent',

// T
'taille_ko' => '@taille@&nbsp;Ko',
'taille_mo' => '@taille@&nbsp;Mo',
'taille_octets' => '@taille@&nbsp;octets',
'texte_actualite_site_1' => 'Quand vos seretz familharizat/ada amb l\'interf&agrave;cia, poiretz clicar sobre &laquo;',
'texte_actualite_site_2' => 'Interf&agrave;cia completa',
'texte_actualite_site_3' => '" per badar mai de possibilitats.',
'texte_creation_automatique_vignette' => 'La creacion automatica de vinhetas de previsualizacion es activada sus aquel sit. S\'installatz a partir d\'aquel formulari d\'imatges au(s) format(s) @gd_formats@, s\'acompanhar&aacute;n d\'una vinheta d\'una talha maximala de @taille_preview@ pix&egrave;ls.',
'texte_documents_associes' => 'Los documents seguents s\'ass&ograve;cian a l\'article,
 mas s\'inserisson pas
 dir&egrave;ctament. Segon la compaginacion dau sit public,
 poir&aacute;n apar&eacute;isser sos forma de documents junts.',
'texte_erreur_mise_niveau_base' => 'Error de basa de donadas pendent la mesa a niv&egrave;l. L\'imatge <b>@fichier@</b> z-es pas passat (article @id_article@).
  Notatz plan aquela refer&eacute;ncia, tornatz assajar la mesa a
 niv&egrave;l, e verificatz pu&egrave;i que los imatges apareissan
 encara dins los articles.',
'texte_erreur_visiteur' => 'Vous avez tent&eacute; d\'acc&eacute;der &agrave; l\'espace priv&eacute; avec un login qui ne le permet pas.', # NEW
'texte_inc_auth_1' => 'S&egrave;tz identificat/ada coma
   <b>@auth_login@</b>, mas aquel login exist&iacute;s pas o pas mai dins la basa.
  Assajatz de vos', # MODIF
'texte_inc_auth_2' => 'tornar connectar',
'texte_inc_auth_3' => ', apr&egrave;s qu\'auretz quitat eventualament, pu&egrave;i
  tornat lan&ccedil;ar v&ograve;stre navigador.',
'texte_inc_config' => 'Las modificacions faitas dins aquestas paginas influ&eacute;ncian ferme lo
 foncionament de v&ograve;stre sit. Vos aconselham de pas lai intervenir tant que siatz pas
 acostumat/ada au foncionament dau sist&egrave;ma SPIP. <br /><br /><b>
 En generau, se conselha f&ograve;rt
 de laissar la charja d\'aquestas paginas au webm&egrave;stre principau de v&ograve;stre sit.</b>',
'texte_inc_meta_1' => 'Lo sist&egrave;ma a rescontrat una error dins l\'escritura dau fich&egrave;ir <code>@fichier@</code>.Volgatz, coma administrator/tritz dau sit,',
'texte_inc_meta_2' => 'verificar los dreits d\'escritura',
'texte_inc_meta_3' => 'dins lo repert&ograve;ri <code>@repertoire@<code>.',
'texte_statut_en_cours_redaction' => 'en cors de redaccion',
'texte_statut_poubelle' => 'au bordilh&egrave;ir',
'texte_statut_propose_evaluation' => 'prepausat per avaloracion',
'texte_statut_publie' => 'publicat en linha',
'texte_statut_refuse' => 'refusat',
'titre_ajouter_mot_cle' => 'APONDRE UN MOT CLAU:',
'titre_breve_proposee' => 'Br&egrave;va prepausada',
'titre_breve_publiee' => 'Br&egrave;va publicada',
'titre_breve_refusee' => 'Br&egrave;va refusada',
'titre_cadre_raccourcis' => '\'CORCHAS:',
'titre_changer_couleur_interface' => 'Chamjar la color de l\'interf&agrave;cia',
'titre_forum' => 'Forum',
'titre_image_admin_article' => 'Pod&egrave;tz administrar aqueste article',
'titre_image_administrateur' => 'Administrator',
'titre_image_aide' => 'D\'ajuda sobre aquel element',
'titre_image_auteur_supprime' => 'Autor suprimit',
'titre_image_redacteur' => 'Redactor sens acc&egrave;s',
'titre_image_redacteur_02' => 'Redactor',
'titre_image_visiteur' => 'Vesitaire',
'titre_joindre_document' => 'J&Oacute;NHER UN DOCUMENT',
'titre_liens_entrants' => 'Liams entrants ',
'titre_mots_cles' => 'MOTS CLAUS',
'titre_probleme_technique' => 'Atencion: un probl&egrave;ma tecnic (servidor SQL) empacha d\'accedir v&egrave;rs aquela part dau sit. Merc&eacute; de v&ograve;stra indulg&eacute;ncia.',
'titre_publier_document' => 'PUBLICAR UN DOCUMENT DINS AQUELA RUBRICA',
'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
'titre_signatures_confirmees' => 'Signatures confirm&eacute;es', # NEW
'titre_statistiques' => 'Estadisticas dau sit',
'titre_titre_document' => 'T&iacute;tol dau document:',
'todo' => '&agrave; venir', # NEW
'trad_reference' => '(article de refer&eacute;ncia)',

// Z
'zbug_balise_b_aval' => '&nbsp;: balisa B en aval',
'zbug_balise_inexistante' => 'Balise @balise@ mal d&eacute;clar&eacute;e pour @from@', # NEW
'zbug_balise_sans_argument' => 'Argument manquant dans la balise @balise@', # NEW
'zbug_boucle' => 'bloca',
'zbug_boucle_recursive_undef' => 'bloca recursiva non definida', # MODIF
'zbug_calcul' => 'calcul', # NEW
'zbug_champ_hors_boucle' => 'Champ @champ@ f&ograve;ra bloca',
'zbug_champ_hors_motif' => 'Champ @champ@ en def&ograve;ra d\'una bloca de motiu @motif@', # MODIF
'zbug_code' => 'c&ograve;de',
'zbug_critere_inconnu' => 'crit&egrave;ri inconegut @critere@', # MODIF
'zbug_distant_interdit' => 'ext&egrave;rne enebit', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'Doublons sur une table sans clef primaire atomique', # NEW
'zbug_doublon_table_sans_index' => 'Doublons sur une table sans index', # NEW
'zbug_erreur_boucle_double' => 'BLOCA@id@: definicion dobla', # MODIF
'zbug_erreur_boucle_fermant' => 'BLOCA@id@: lo tag barrador manca', # MODIF
'zbug_erreur_boucle_syntaxe' => 'Sintaxi bloca incorr&egrave;cta', # MODIF
'zbug_erreur_compilation' => 'Erreur de compilation', # NEW
'zbug_erreur_execution_page' => 'error d\'execucion de la pagina', # MODIF
'zbug_erreur_filtre' => 'Error: filtre <b>&laquo; @filtre@ &raquo;</b> non definit', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} s\'aplica sonque a las blocas (FORUMS) o (RUBRIQUES)', # MODIF
'zbug_erreur_squelette' => 'Error(s) dins l\'esqueleta',
'zbug_hors_compilation' => 'Hors Compilation', # NEW
'zbug_info_erreur_squelette' => 'Error sobre lo sit',
'zbug_inversion_ordre_inexistant' => 'inversion d\'un &ograve;rdre inexistent', # MODIF
'zbug_pagination_sans_critere' => 'Balise #PAGINATION sans crit&egrave;re {pagination} ou employ&eacute; dans une boucle recursive', # NEW
'zbug_parametres_inclus_incorrects' => 'Param&egrave;tres d\'inclusion incorr&egrave;ctes', # MODIF
'zbug_profile' => 'Temps de calcul&nbsp;: @time@', # NEW
'zbug_resultat' => 'resultat',
'zbug_serveur_indefini' => 'servidor SQL indefinit', # MODIF
'zbug_statistiques' => 'Statistiques des requ&ecirc;tes SQL class&eacute;es par dur&eacute;e', # NEW
'zbug_table_inconnue' => 'Taula SQL &laquo;@table@&raquo; desconeguda',
'zxml_connus_attributs' => 'attributs connus', # NEW
'zxml_de' => 'de', # NEW
'zxml_inconnu_attribut' => 'attribut inconnu', # NEW
'zxml_inconnu_balise' => 'balise inconnue', # NEW
'zxml_inconnu_entite' => 'entit&eacute; inconnue', # NEW
'zxml_inconnu_id' => 'ID inconnu', # NEW
'zxml_mais_de' => 'mais de', # NEW
'zxml_non_conforme' => 'n\'est pas conforme au motif', # NEW
'zxml_non_fils' => 'n\'est pas un fils de', # NEW
'zxml_nonvide_balise' => 'balise non vide', # NEW
'zxml_obligatoire_attribut' => 'attribut obligatoire mais absent dans', # NEW
'zxml_succession_fils_incorrecte' => 'succession des fils incorrecte', # NEW
'zxml_survoler' => 'survoler pour voir les corrects', # NEW
'zxml_valeur_attribut' => 'valeur de l\'attribut', # NEW
'zxml_vide_balise' => 'balise vide', # NEW
'zxml_vu' => 'vu auparavant', # NE
);

?>
